==================
Django Nomadlytics
==================

Overview
========

This Django app offers a very light abstraction layer to use a single
method of tracking your data into different SaaS analytics services such
as Mixpanel, Google Analytics, or others.

Read the latest documentation on `Read the docs`_ for installation,
configuration and customization instructions.

.. _`Read the docs`: http://readthedocs.org/docs/django-nomadlytics/en/latest/

